@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.70';
+our $VERSION = '0.71';
 
 use List::Util 'first';
 
@@ -220,7 +220,7 @@ sub _detect_linux_distribution_lsb_release {
 sub _detect_linux_distribution_fallback {
     if (open my $fh, '<', '/etc/redhat-release') {
 	my $contents = <$fh>;
-	if ($contents =~ m{^(CentOS|RedHat|Fedora) (?:Linux )?release (\d+)\S*( \((.*?)\))?}) {
+	if ($contents =~ m{^(CentOS|Rocky|RedHat|Fedora) (?:Linux )?release (\d+)\S*( \((.*?)\))?}) {
 	    return {linuxdistro => $1, linuxdistroversion => $2, linuxdistrocodename => defined $3 ? $3 : ''};
 	}
     }
@@ -238,6 +238,7 @@ sub _detect_linux_distribution_fallback {
 		 9  => 'stretch',
 		 10 => 'buster',
 		 11 => 'bullseye',
+		 12 => 'bookworm',
 		}->{$info{linuxdistroversion}};
 	    return \%info;
 	} elsif ($line =~ m{^(Ubuntu) (\d+\.\d+)}) {
@@ -249,6 +250,7 @@ sub _detect_linux_distribution_fallback {
 		 '16.04' => 'xenial',
 		 '18.04' => 'bionic',
 		 '20.04' => 'focal',
+		 '22.04' => 'jammy',
 		}->{$info{linuxdistroversion}};
 	    return \%info;
 	} else {
@@ -267,7 +269,7 @@ sub _is_linux_debian_like {
 
 sub _is_linux_fedora_like {
     my(undef, $linuxdistro) = @_;
-    $linuxdistro =~ m{^(fedora|redhat|centos)$};
+    $linuxdistro =~ m{^(fedora|redhat|centos|rocky)$};
 }
 
 sub _is_apt_installer { shift->{installer} =~m{^(apt-get|aptitude)$} }
@@ -826,7 +828,7 @@ The distribution name is lowercased.
 
 There are special values C<~debian> to match Debian-like distributions
 (Ubuntu and LinuxMint) and C<~fedora> to match Fedora-like
-distributions (RedHat and CentOS).
+distributions (RedHat, CentOS and Rocky Linux).
 
 =item linuxdistrocodename => I<$value>
 
